@@ -61,24 +61,22 @@ class Formatters:
         Convert time in a string format to seconds.
 
         Args:
-            time: The time in string format with s/min/h/d/w/m/y. Note: use 'min' for minutes.
+            time: The time in string format with s/m/h/d/w.
 
         Returns:
             The time in seconds.
         """
         time = time.lower()
-        # the last char of the time, e.g. s, min, h, d, w, m, y
+        # the last char of the time, e.g. s, m, h, d, w
         time_last_chars = time[1:]
         times = {
             "s": 1,
-            "min": 60,
+            "m": 60,
             "h": 3600,
             "d": 86400,
             "w": 604800,
-            "m": 2630000,
-            "y": 31536000,
         }
-        # Check if last char is in the times dictionary
-        if not time_last_chars in times:
+        # check if the last char is in the times dict
+        if time_last_chars not in times:
             return -1
-        return int(time_last_chars) * times[time_last_chars]
+        return int(time[:-1]) * times[time_last_chars]
